# DeTEE Cloud

The mission of DeTEE is to create a decentralized cloud solution that functions as an open market for hardware resources. The DeTEE protocol is connecting the customers (mostly software companies) and the service providers (node operators), ensuring the the business activity of all participants runs smooth. In order to make the decentralized network feel like a cloud platform, DeTEE inspired the user experience from popular cloud platforms (Kubernetes, Openstack, AWS, GCP), and optimized and simplified the flow to the benefit of the end user.

In order to make the environment business-friendly, guarantees regarding security and privacy must be offered by the software powering the platform. In order to achieve this, DeTEE leverages the hardware capabilities of TEEs into the core of the platform, working already with Intel SGX and AMD SEV-SNP, and planning to integrate Intel TDX, AMD Trustzone and NVIDIA H100 GPUs in the future. As we can't be responsible for the reliability of the hardware itself, the strategy of DeTEE envolves offering users the possibility to chose the hardware they work with, and to easily migrate their applications from one system to another.

The DeTEE cloud will soon enter the testnet phase, allowing members of our community to deploy containers and VMs on the DeTEE network. The testnet does not guarantee stability (actually it guarantees disruptions, as we are actively developing the software).

# Components

DeTEE is built of multiple components that are already under development, as follows:
- **The Brain**: a decentralized contract manager (functioning very much like an Oracle) that runs on top of the DeTEE encryption layer
  - [x] stores your account balanace (not matter if you are a user or a node operator)
  - [x] allows you to create contracts for VMs and containers
  - [ ] allows you to create contracts for GPUs
  - [ ] allows users to vote for the upgrades of the platform
  - [x] stores ratings for users
  - [ ] allows you to deposit and withdraw DeTEE tokens via different blockchains

- **(Intel) SGX Daemon**: Software that powers the SGX node, allowing customers to run containers
  - [x] allows you to run containers based on [occlum](https://github.com/occlum/occlum)
  - [x] allows you to expose ports on the public IP of the node
  - [ ] offers domain services and TLS termination based on intel SGX
  - [x] allows payment model based on reservation of hardware

- **(AMD) SNP Daemon**: Software that powers the SNP node, allowing customers to run VMs
  - [x] allows you to run VMs based using ArchLinux, Ubuntu and Fedora as a base
  - [x] allows you to expose ports on the public IP of the node
  - [x] allows dedicated public IPv4 and public IPv6 addresses for the VMs
  - [x] allows payment model based on reservation of hardware

- **DeTEE CLI**: end-user CLI that allows you manage resources on the DeTEE platform
  - [x] allows you to manage your account data
  - [x] allow you to manage VMs
  - [x] allow you to manage containers
  - [x] allow you to manage containers
  - [ ] offers warning about containers and VMs facing performance issues or decomissioning
  - [ ] enables withdrawal of tokens to public blockchains
  - [ ] manage access to resources based on teams

- **DeTEE Web GUI**: Will offer the same features as the CLI in a user friendly manner

- **Orchcestrator**: advanced cloud service that offers high availability and clustering for software services running on the DeTEE platform
  - [ ] management of secrets using DeTEE encryption
  - [x] deployment of swarms of containers across multiple nodes
  - [ ] create groups of highly available VMs based on the same template
  - [ ] automatic scaling of resources based on load
  - [ ] automatic migration of resources in case of hardware failure (or decomissioning)
  - [ ] multi-region clusters

Future components (currently not under development):
- **(ARM) TrustZone Daemon**: Software that powers the SNP node, allowing customers to run VMs
- **(NVIDIA) GPU Daemon**: Software that powers the SNP node, allowing customers to run VMs


# Getting access

In order to test our cloud, you will first need an airdrop of testnet tokens. Here are a few ways to qualify for airdrops:
- Join our [Discord Server](https://discord.gg/zrK56XMe)
- Follow [DeTEE on Twitter](https://x.com/detee_network)
- Follow [DeTEE on Instagram](https://www.instagram.com/detee_network/)
- Follow [DeTEE on Linkedin](https://www.linkedin.com/company/105187289)
- Follow [Gheorghe](https://www.linkedin.com/in/ghe0/) on Linkedin. Gheorghe loves attention so this will get you extra points.
- Follow [Valy](https://www.linkedin.com/in/valentyn-faychuk-589674204/) on Linkedin.
- Post about DeTEE on social media.
- Post a review of the the [hacker-challenge](https://gitea.detee.cloud/general/hacker-challenge/)
- Be active in the community and provide feedback to help us improve our service
- Report bugs
- Help us improve documentation

Please be aware that the airdrops are awarded based on the activity, meaning being more involved will allow you to get more tokens, which will grant you access to more testnet resources.

To collect the airdrops after performing the activities above, write to us on Discord in the [📦claim-airdrops](https://discord.gg/zmR3Bzxz) channel. Summarize your activity with links (for example, links to social media posts you made about DeTEE).

Once you secured an airdrop in your DeTEE wallet, you can start using the DeTEE CLI.
